/***************************************************************************
 *   Copyright (C) 2010 by Consciousness								   *
 *   muwee@gala.net														   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include <QtGui>
#include <QDebug>
#include <kapplication.h>
#include <kconfig.h>
#include <kglobal.h>
#include <kgenericfactory.h>
#include <kglobalsettings.h>
#include <kstandarddirs.h>
#include <klocale.h>
#include <kaboutdata.h>
#include <kaboutapplicationdialog.h>

#include "form1.h"
#include "ui_form.h"


static KAboutData createAboutData()
{
	 KAboutData aboutData("gtk-kde4", "kcm_gk4", ki18n("GTK-KDE4"), "0.9.5",
                        ki18n("Changes style of your GTK apps in KDE4"), KAboutData::License_GPL_V2,
			ki18n("(c) 2010 Consciousness"), KLocalizedString(), "http://kde-apps.org");
	aboutData.addAuthor(ki18n("Konchunas Yulian"));
	aboutData.setBugAddress("muwee@gala.net");
	aboutData.setProgramIconName("gk4icon.png");
	aboutData.addCredit(ki18n("Slava Pustovalov"),ki18n("Icon creator"));
	aboutData.addCredit(ki18n("Fans"),ki18n("Make me think someone needs this app"));
	return aboutData;
}

K_PLUGIN_FACTORY(form1Factory, registerPlugin<form1>();)
K_EXPORT_PLUGIN(form1Factory(createAboutData()));

form1::form1( QWidget * parent, const QVariantList&) 
	: KCModule(form1Factory::componentData(), parent)
{
	setupUi(this);
	version="0.9.5";
	sett=new QSettings("gtk-kde4", "gtk-kde4");
	
	currentStyleName=KGlobal::config()->group("General").readEntry("widgetStyle");
	currentIconsName=KGlobal::config()->group("Icons").readEntry("Theme");
	
	dir.setPath("/usr/share/themes/");
	if (dir.exists()) 
	{
		filesel = dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
		QDir::setCurrent("/usr/share/themes/");
		for (i=0; i<filesel.size(); i++) 
		{
			if (!QDir(filesel.at(i)+"/gtk-2.0").exists())
			{
				filesel.removeAt(i);
				i--;
			}
		}
	}
	//create ~/.themes and ~/.icons dirs
	if (!QDir(QDir::homePath()+"/.icons").exists())
		QDir::home().mkdir(".icons");
	if (!QDir(QDir::homePath()+"/.themes").exists())
		QDir::home().mkdir(".themes");

	//copy qt4 and gk4ico if they aren't present
	if (!QDir(QDir::homePath()+"/.themes/qt4").exists())	
		QProcess::execute("cp -R /usr/share/themes/qt4 "+ QDir::homePath() +"/.themes/");
	if (!QDir(QDir::homePath()+"/.icons/gk4ico").exists())	
		QProcess::execute("cp -R /usr/share/icons/gk4ico "+ QDir::homePath() +"/.icons/");
	//copy configs if the new version
	if (sett->value("Version").toString()!=version)
	{
		QFile::copy("/usr/share/themes/qt4/gtk-2.0/gtkrc", QDir::homePath() +"/.themes/qt4/gtk-2.0/");
		QProcess::execute("cp -R /usr/share/icons/gk4ico "+ QDir::homePath() +"/.icons/");
		sett->setValue("Version", version);
	}
	
	varstr=QDir::homePath().append("/.themes");
	dirqt.setPath(varstr+"/qt4");
	if (dirqt.exists())
		comboBox->insertItem(0,i18n("Use current KDE style")+" ("+currentStyleName+")");
	if (QDir(QDir::homePath().append("/.icons/gk4ico")).exists())
		comboBox2->insertItem(0,i18n("Use current KDE icons")+" ("+currentIconsName+")");
	//themes finding
	//how it works: creates list of themes from /usr/share/themes, appends list from ~/.themes,sorts and adds to comboBox
	dir.setPath(varstr);
	hilesel = dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
	QDir::setCurrent(varstr);
	for (i=0; i<hilesel.size(); i++) 
	{
		if (QDir(hilesel.at(i)+"/gtk-2.0").exists())
			filesel.append(hilesel.at(i));
	}	
	if (!filesel.isEmpty()) 
	{
		filesel.sort();
		for (i=0; i<filesel.size(); i++) 
			if (filesel.at(i)!="qt4") comboBox->addItem(filesel.at(i));
	}
	//icons finding
	//works like themes finding
	dir.setPath("/usr/share/icons/");
	if (dir.exists()) 
	{
		filesel = dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
		QDir::setCurrent("/usr/share/icons/");
		for (i=0; i<filesel.size(); i++) 
		{
			if (!QFile(filesel.at(i)+"/index.theme").exists()
			||  QDir(filesel.at(i)+"/cursors").exists())
			{
				filesel.removeAt(i);
				i--;
			}
		}
	}
	varstr=QDir::homePath().append("/.icons");
	dir.setPath(varstr);
	if (dir.exists()) 
	{
		hilesel = dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot);
		QDir::setCurrent(varstr);
		for (i=0; i<hilesel.size(); i++) 
		{
			if (QFile(hilesel.at(i)+"/index.theme").exists()
			&&  !QDir(hilesel.at(i)+"/cursors").exists())
			{
				filesel.append(hilesel.at(i));
			}
		}	
	}
	if (!filesel.isEmpty()) 
	{
		filesel.sort();
		for (i=0; i<filesel.size(); i++) 
			if (filesel.at(i)!="gk4ico") comboBox2->addItem(filesel.at(i));
	}
	//colors buttons
	menuBarTextColor->setColor(qApp->palette().color(QPalette::WindowText));
	menuBarTextColorMO->setColor(qApp->palette().color(QPalette::WindowText));
	menuTextColor->setColor(qApp->palette().color(QPalette::WindowText));
	menuTextColorMO->setColor(qApp->palette().color(QPalette::WindowText));
	
	//others
	qsr = new QSvgRenderer();
	kdehome = KGlobal::dirs()->localkdedir();
	p=0;
	timeOn=false; ms=0;
	fileOpen=false;
	setButtons(KCModule::Apply);
	setFocusPolicy(Qt::ClickFocus);
	if (sett->value("FontFamily").toString().isNull()) sett->setValue("FontFamily", "DejaVu Sans");
	if (sett->value("FontSize").toInt()==0) sett->setValue("FontSize", 9);
	fstr=sett->value("FontFamily").toString();
	fsz=sett->value("FontSize").toInt();
	fst=sett->value("FontStyle").toString();
	fw=sett->value("FontWeight").toString();
	comboBox3->addItem("Loading your current font...");
	fs=fstr+" "+fw+" "+fst+" "+QString::number(fsz);
	fs=fs.simplified();
	
	if (sett->value("UseSpecialColors").toBool())
	{
		useSpecialColors->setChecked(true);
		menuBarTextColor->setColor(sett->value("MenuBarTextColor").value<QColor>());
		menuBarTextColorMO->setColor(sett->value("MenuBarTextColorMO").value<QColor>());
		menuTextColor->setColor(sett->value("MenuTextColor").value<QColor>());
		menuTextColorMO->setColor(sett->value("MenuTextColorMO").value<QColor>());
	}
	
	com1Ch();
	
	//this is needed after languages section for correct translation
	comboBox3->addItem(i18n("Choose other font")+" ("+fs+") ");
	fontNameUpdate();
	
	//slots
	connect(aboutButton, SIGNAL(released()), this, SLOT(AboutReleased()));
	connect(KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()), this, SLOT(fontNameUpdate()));
	connect(KGlobalSettings::self(), SIGNAL(appearanceChanged()), this, SLOT(styleNameUpdate()));
	connect(comboBox, SIGNAL(currentIndexChanged(int)),this, SLOT(com1Ch()));
	connect(applyBox, SIGNAL(stateChanged(int)),this, SLOT(changed()));
	connect(comboBox2,SIGNAL(currentIndexChanged(int)),this,SLOT(changed()));
	connect(useSpecialColors,SIGNAL(clicked(bool)),this,SLOT(changed()));
	connect(comboBox3,SIGNAL(activated(int)),this,SLOT(com3Ch()));
	connect(sudoButton, SIGNAL(released()), this, SLOT(sudoSymlink()));
	connect(menuBarTextColor,SIGNAL(released()), this, SLOT(changed()));
	connect(menuBarTextColorMO,SIGNAL(released()), this, SLOT(changed()));
	connect(menuTextColorMO,SIGNAL(released()), this, SLOT(changed()));
	connect(menuTextColor,SIGNAL(released()), this, SLOT(changed()));
	
}
 
void form1::save ()
{
	if (QProcessEnvironment::systemEnvironment().value("GTK2_RC_FILES").contains(QDir::homePath()+"/.gtkrc-2.0-kde4"))
		if (QFile::exists(QDir::homePath()+"/.gtkrc-2.0-kde4"))
			if (QFile(QDir::homePath()+"/.gtkrc-2.0-kde4").size()>1) //not sure that 1 byte can cause something conflicting, but can handle accidental space symbol
			{
				QMessageBox::warning(this,i18n("Conflict file found"),i18n("There is a .gtkrc-2.0-kde4 file found in your home folder. This file is used by other "
				"GTK theming engines and it can override settings of gtk-kde4. Possible workarounds are:\n 1.Simply remove ~/.gtkrc-2.0-kde4\n "
				"2.Uninstall app using it (kcm-gtk, gtk-qt-engine-kde4 and so on)\n 3.Delete record from environmental variables GTK_RC_FILES and GTK2_RC_FILES\n "
				"4.Empty the file and set read-only permissions"));
			}
	pal=qApp->palette();
	colors.clear();
	/*0*/colors<<pal.color(QPalette::Base).name();
	/*1*/colors<<pal.color(QPalette::Disabled, QPalette::Base).name();
	/*2*/colors<<pal.color(QPalette::Text).name();
	/*3*/colors<<pal.color(QPalette::Highlight).name();
	/*4*/colors<<pal.color(QPalette::HighlightedText).name();
	/*5*/colors<<pal.color(QPalette::Window).name();
	/*6*/colors<<pal.color(QPalette::Disabled,QPalette::Window).name();
	/*7*/colors<<pal.color(QPalette::Disabled,QPalette::WindowText).name();
	/*8*/colors<<pal.color(QPalette::WindowText).name();
	/*9*/colors<<pal.color(QPalette::Disabled,QPalette::Text).name();
	 //saving menucolors
	sett->setValue("UseSpecialColors", useSpecialColors->isChecked());
	sett->setValue("MenuBarTextColor", menuBarTextColor->color());
	sett->setValue("MenuBarTextColorMO", menuBarTextColorMO->color());
	sett->setValue("MenuTextColor", menuTextColor->color());
	sett->setValue("MenuTextColorMO", menuTextColorMO->color());
	//writing to file
	if (fileOpen==false)
	{
		varstr = KStandardDirs::locate("config", "gtkrc-2.0");
		if (varstr.isNull())
		{
			//QProcess::execute("touch "+kdehome+"share/config/gtkrc-2.0");
			varstr=kdehome+"share/config/gtkrc-2.0";
		}
		file.setFileName(varstr);

		varstr = KStandardDirs::locate("config", "gtkrc");
		if (varstr.isNull())
		{
			//QProcess::execute("touch "+kdehome+"share/config/gtkrc");
			varstr=kdehome+"share/config/gtkrc";
		}
		varfile.setFileName(varstr);
	}
	file.setPermissions(QFile::WriteOwner);
	varfile.setPermissions(QFile::WriteOwner);
	file.remove();
	if (file.open(QFile::WriteOnly))
	{
		fileOpen=true;
		QTextStream out(&file);
		if (comboBox->currentIndex()!=0)
		{
			out<<"include \"/usr/share/themes/"<<comboBox->currentText()<<"/gtk-2.0/gtkrc\""<<endl;
			out<<"include \""<<QDir::homePath()<<"/.themes/"<<comboBox->currentText()<<"/gtk-2.0/gtkrc\""<<endl;
		}
		else
		{
			/*if (currentStyleName.toLower()=="qtcurve") //automatical QtCurve applying
			{
				out<<"include \"/usr/share/themes/QtCurve/gtk-2.0/gtkrc\""<<endl;
				out<<"include \""<<QDir::homePath()<<"/.themes/QtCurve/gtk-2.0/gtkrc\""<<endl;
			}	
			else*/
				out<<"include \""<<QDir::homePath()<<"/.themes/qt4/gtk-2.0/gtkrc\""<<endl;
		}
		if (applyBox->checkState()==2 || comboBox->currentIndex()==0)
		{
			out<<"style \"user\""<<endl;
			out<<"{ "<<endl;
			out<<"fg[NORMAL] = \""<<colors.at(8)<<"\""<<endl;
			out<<"bg[NORMAL] = \""<<colors.at(5)<<"\""<<endl;
			out<<"text[NORMAL] = \""<<colors.at(2)<<"\""<<endl;
			out<<"base[NORMAL] = \""<<colors.at(0)<<"\""<<endl;
			
			out<<"fg[ACTIVE] = \""<<colors.at(8)<<"\""<<endl;
			out<<"bg[ACTIVE] = \""<<colors.at(5)<<"\""<<endl;
			out<<"text[ACTIVE] = \""<<colors.at(2)<<"\""<<endl;
			out<<"base[ACTIVE] = \""<<colors.at(0)<<"\""<<endl;
		
			out<<"fg[PRELIGHT] = \""<<colors.at(8)<<"\""<<endl;
			out<<"bg[PRELIGHT] = \""<<colors.at(5)<<"\""<<endl;
			out<<"text[PRELIGHT] = \""<<colors.at(4)<<"\""<<endl;
			out<<"base[PRELIGHT] = \""<<colors.at(3)<<"\""<<endl;
		
			out<<"fg[SELECTED] = \""<<colors.at(8)<<"\""<<endl;
			out<<"bg[SELECTED] = \""<<colors.at(5)<<"\""<<endl;
			out<<"text[SELECTED] = \""<<colors.at(4)<<"\""<<endl;
			out<<"base[SELECTED] = \""<<colors.at(3)<<"\""<<endl;
			
			out<<"fg[INSENSITIVE] = \""<<colors.at(7)<<"\""<<endl;
			out<<"bg[INSENSITIVE] = \""<<colors.at(6)<<"\""<<endl;
			out<<"text[INSENSITIVE] = \""<<colors.at(9)<<"\""<<endl;
			out<<"base[INSENSITIVE] = \""<<colors.at(1)<<"\""<<endl;
			out<<"GtkTreeView::odd_row_color=\""<<pal.color(QPalette::Base).name()<<"\""<<endl;
			out<<"GtkTreeView::even_row_color=\""<<pal.color(QPalette::AlternateBase).name()<<"\""<<endl;
		 
			out<<"}"<<endl;
			out<<"widget_class \"*\" style \"user\""<<endl;
			
			out<<"style \"tooltips\""<<endl;
			out<<"{ "<<endl;
			out<<"bg[NORMAL] = \""<<pal.color(QPalette::ToolTipBase).name()<<"\""<<endl;
			out<<"fg[NORMAL] = \""<<pal.color(QPalette::ToolTipText).name()<<"\""<<endl;
			out<<"}"<<endl;
			out<<"widget \"gtk-tooltips\" style \"tooltips\""<<endl;
			
			if (useSpecialColors->isChecked())
			{
				out<<"style \"menuitem\""<<endl;
				out<<"{"<<endl;
				out<<"fg[NORMAL] = \""<<menuTextColor->color().name()<<"\""<<endl;
				out<<"fg[PRELIGHT] = \""<<menuTextColorMO->color().name()<<"\""<<endl;
				out<<"fg[SELECTED] = \""<<menuTextColorMO->color().name()<<"\""<<endl;
				out<<"fg[ACTIVE] = \""<<menuTextColorMO->color().name()<<"\""<<endl;
				out<<"}"<<endl;
				out<<"widget_class \"*MenuItem*\" style \"menuitem\""<<endl;	
				
				out<<"style \"menubar\""<<endl;
				out<<"{"<<endl;
				out<<"fg[NORMAL] = \""<<menuBarTextColor->color().name()<<"\""<<endl;
				out<<"fg[PRELIGHT] = \""<<menuBarTextColorMO->color().name()<<"\""<<endl;
				out<<"text[NORMAL] = \""<<menuBarTextColor->color().name()<<"\""<<endl;
				out<<"text[PRELIGHT] = \""<<menuBarTextColorMO->color().name()<<"\""<<endl;
				out<<"}"<<endl;
				out<<"widget_class \"*MenuBar*\" style \"menubar\""<<endl;
				out<<"class \"GtkMenuBar\" style \"menubar\""<<endl;
			}
		}
		if (comboBox->currentIndex()!=0)
			out<<"#gtk-theme-name=\""<<comboBox->currentText()<<"\""<<endl;
		else 
			out<<"#gtk-theme-name=\"qt4\""<<endl;
		if (comboBox3->currentIndex()!=0)
			out<<"gtk-font-name=\""<<fstr<<" "<<fw<<" "<<fst<<" "<<fsz<<"\""<<endl;
		else
		{	fs=QApplication::font().family();
			fs+=" "+fontWeight(QApplication::font().weight());
			fs+=" "+fontStyle(QApplication::font().style());
			fs+=" "+QString::number(QApplication::font().pointSize());
			fs=fs.simplified();
			out<<"gtk-font-name=\""<<fs<<"\""<<endl;
		}
		if (comboBox2->currentIndex()!=0)
			out<<"gtk-icon-theme-name=\""<<comboBox2->currentText()<<"\""<<endl;
		else 
			out<<"gtk-icon-theme-name=\"gk4ico\""<<endl;
		out<<"gtk-icon-sizes = \"panel-menu=16,16:panel=16,16:gtk-button=22,22:gtk-large-toolbar=22,22\"";
		file.flush();
		file.close();
	}
	file.setPermissions(QFile::ReadOwner | QFile::ReadGroup | QFile::ReadOther);
	varfile.remove();
	QProcess::execute("ln -s "+file.fileName()+" "+varfile.fileName());
	sett->setValue("StyleIndex", comboBox->currentIndex());
	sett->setValue("IconIndex", comboBox2->currentIndex());
	sett->setValue("FontIndex", comboBox3->currentIndex());
	sett->setValue("StyleText", comboBox->currentText());
	sett->setValue("IconText", comboBox2->currentText());
	sett->setValue("ApplyColors", applyBox->checkState());
	if (	(comboBox->currentIndex()==0 ||
		comboBox2->currentIndex()==0 ||
		comboBox3->currentIndex()==0) &&
		!QFile(kdehome+"share/config/gk4lock").exists())
	{
		QProcess::execute("kstart gtk-kde4");
		QProcess::execute("touch "+kdehome+"share/config/gk4lock");
	}
	else if (QFile(kdehome+"share/config/gk4lock").exists() &&
		comboBox->currentIndex()!=0  &&
		comboBox2->currentIndex()!=0 &&
		comboBox3->currentIndex()!=0)
	{	
		proc.start("pidof gtk-kde4");
		if (proc.waitForFinished()) varstr = proc.readLine();
		proc.close();
		QProcess::execute("kill "+varstr);
		QFile(kdehome+"share/config/gk4lock").remove();
	}
	
}

void form1::AboutReleased()
{
	KAboutApplicationDialog *ap = new KAboutApplicationDialog(form1Factory::componentData().aboutData());
	ap->exec();
}

void form1::CFReleased() {
	bool ok;
	dialF.setFamily(fstr);
	dialF.setPointSize(fsz);
	QFont font = QFontDialog::getFont(&ok,dialF);
	if (ok)
	{
		fstr=font.family();
		fsz=font.pointSize();	
		fst=fontStyle(font.style());
		fw=fontWeight(font.weight());
		fs=fstr+" "+fw+" "+fst+" "+QString::number(fsz);
		fs=fs.simplified();
		comboBox3->setItemText(1,i18n("Choose other font")+" ("+fs+")");
		sett->setValue("FontFamily", fstr);
		sett->setValue("FontSize", fsz);
		sett->setValue("FontStyle", fst);
		sett->setValue("FontWeight", fw);
	}
}

QString form1::fontStyle(int j)
{
	if (j==0) return QString("");
	else if (j==1) return QString("Italic");
	else if (j==2) return QString("Oblique");
	else return QString("Something wrong! Please, report a bug");
}

QString form1::fontWeight(int i)
{
	if (i==25) return QString("Light");
	else if (i==50) return QString("");
	else if (i==63) return QString("DemiBold");
	else if (i==75) return QString("Bold");
	else if (i==87) return QString("Black");
	else return QString("Something wrong! Please, report a bug");
}

void form1::fontNameUpdate()
{
	fs=QApplication::font().family();
	fs+=" "+fontWeight(QApplication::font().weight());
	fs+=" "+fontStyle(QApplication::font().style());
	fs+=" "+QString::number(QApplication::font().pointSize());	
	fs=fs.simplified();
	comboBox3->setItemText(0,i18n("Use current KDE font")+" ("+fs+") ");
}

void form1::styleNameUpdate()
{
	currentStyleName=KGlobal::config()->group("General").readEntry("widgetStyle");
	if (dirqt.exists())
		comboBox->setItemText(0,i18n("Use current KDE style")+" ("+currentStyleName+")");
}


void form1::iconsNameUpdate()
{
	currentIconsName=KGlobal::config()->group("Icons").readEntry("Theme");
		if (QDir(QDir::homePath().append("/.icons/gk4ico")).exists())
		comboBox2->setItemText(0,i18n("Use current KDE icons")+" ("+currentIconsName+")");
}


void form1::com1Ch()
{
	changed();
	if (comboBox->currentIndex()==0)
	{
		applyBox->setChecked(true);
		applyBox->setDisabled(true);		
	}
	else
		applyBox->setDisabled(false);
	/*if (comboBox->currentIndex()%2==0)
	{
			styledRadioButton->setStyle(new QMotifStyle);
	}
	else 
	{
		styledRadioButton->setStyle(new QGtkStyle);
	}*/
//	styled->polish(styledPushButton);
	
	//styledCheckBox->repaint();	
}

void form1::com2Ch()
{
	changed();
}

void form1::com3Ch()
{
	if (comboBox3->currentIndex()==1)
	{
		CFReleased();
	}
	changed();
}

//have to be svg support
void form1::fromSvg(QString name,QString newname)
{
/*	if (QFile(kit->dir()+isize+iname+name+".svg").exists())
		qsr->load(QString(kit->dir()+isize+iname+name+".svg"));
	else qsr->load(QString(kit->dir()+isize+iname+name+".svg"));
	if (qsr->isValid())
	{
		QPixmap *pix = new QPixmap(32,32);
		QPainter *paint = new QPainter(pix);
		for (i=2; i>=0; i--)
		{
			if (i==0)
			{
				isize = "16x16";
				*pix=pix->copy(QRect(0,0,16,16));
			}
			if (i==1)
			{
				isize = "22x22";
				*pix=pix->copy(QRect(0,0,22,22));
			}
			if (i==2)
			{
				isize = "32x32";
				*pix=pix->copy(QRect(0,0,32,32));
			}
			pix->fill(Qt::transparent);
			qsr->render(paint);
			if (!QFile(QDir::homePath()+"/.icons/gk4ico/"+isize+iname+newname+".png").exists())
				pix->save(QDir::homePath()+"/.icons/gk4ico/"+isize+iname+newname+".png");
		}
	}*/
}


void form1::sudoSymlink()
{
	//workaround  to ensure it is possible to locate gtkrc-2.0
	varstr = KStandardDirs::locate("config", "gtkrc-2.0");
	if (varstr.isNull())
		varstr=kdehome+"share/config/gtkrc-2.0";
	if (QFile::exists("/root/.gtkrc-2.0"))
	{
		QMessageBox::warning(this,i18n("Problem making symlink"),i18n("Cannot make the symlink because file /root/gtkrc-2.0 already exists."
			"If you did this operation before you don't need to do it again, but if you didn't you may want to rename or delete .gtkrc-2.0 in /root folder and press this button again."));
	}
	else
	{
		Action act("org.kde.kcmgk.makesymlink");
		act.setHelperID("org.kde.kcmgk");
		QVariantMap vMap = act.arguments();
		vMap["file"]=varstr;
		vMap["homeFolder"]=QDir::homePath();
		act.setArguments(vMap);
		act.authorize();
		act.execute();
	}
}

void form1::load()
{
	comboBox->setCurrentIndex((sett->value("StyleIndex")).toInt());
	comboBox2->setCurrentIndex((sett->value("IconIndex")).toInt());
	comboBox3->setCurrentIndex((sett->value("FontIndex")).toInt());
	changed();
}
void form1::defaults(){}
